@@ -18,3 +18,8 @@ class DebugMixin(ConfigMixin):
         # However, it must come after any other middleware that encodes the response’s content,
         # such as GZipMiddleware.
         configuration.MIDDLEWARE.insert(0, 'debug_toolbar.middleware.DebugToolbarMiddleware')
+
+    DEBUG_TOOLBAR_CONFIG = {
+        # The default size often is too small, causing an inability to view queries
+        'RESULTS_CACHE_SIZE': 250,
+    }
