@@ -29,6 +29,7 @@ class DjangoMixin(ConfigMixin):
             'django.contrib.contenttypes',
             'django.contrib.sessions',
             'django.contrib.messages',
+            'django.contrib.humanize',
         ]
         configuration.MIDDLEWARE += [
             'django.middleware.security.SecurityMiddleware',
@@ -67,7 +68,9 @@ class DjangoMixin(ConfigMixin):
         },
     ]
 
-    DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'
+    # Until https://github.com/pennersr/django-allauth/issues/2826 is fixed and released,
+    # this must be AutoField
+    DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
 
     # Password validation
     # https://docs.djangoproject.com/en/3.0/ref/settings/#auth-password-validators
